# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-01-26 22:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('rest_framework_tracking', '0003_add_errors'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='apirequestlog',
            options={'verbose_name': 'API Request Log'},
        ),
    ]
