# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2017-01-18 16:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('rest_framework_tracking', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='apirequestlog',
            name='view',
            field=models.CharField(db_index=True, default='', max_length=200),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='apirequestlog',
            name='view_method',
            field=models.CharField(db_index=True, default='', max_length=200),
            preserve_default=False,
        ),
    ]
